@@ -268,6 +268,16 @@ class FormRequestTest(RequestTest):
         self.assertEqual(fs['one'], ['1'])
         self.assertEqual(fs['two'], ['2'])
 
+    def test_from_response_override_method(self):
+        response = _buildresponse(
+                '''<html><body>
+                <form action="/app"></form>
+                </body></html>''')
+        request = FormRequest.from_response(response)
+        self.assertEqual(request.method, 'GET')
+        request = FormRequest.from_response(response, method='POST')
+        self.assertEqual(request.method, 'POST')
+
     def test_from_response_submit_first_clickable(self):
         response = _buildresponse(
             """<form action="get.php" method="GET">
@@ -555,17 +565,6 @@ class FormRequestTest(RequestTest):
         fs = _qs(req)
         self.assertEqual(fs, {'i1': ['i1v1'], 'i2': ['']})
 
-    def test_from_response_input_hidden(self):
-        res = _buildresponse(
-            '''<form>
-            <input type="hidden" name="i1" value="i1v1">
-            <input type="hidden" name="i2">
-            <input type="hidden">
-            </form>''')
-        req = self.request_class.from_response(res)
-        fs = _qs(req)
-        self.assertEqual(fs, {'i1': ['i1v1'], 'i2': ['']})
-
     def test_from_response_input_textarea(self):
         res = _buildresponse(
             '''<form>
@@ -599,6 +598,26 @@ class FormRequestTest(RequestTest):
         fs = _qs(req)
         self.assertEqual(set(fs), set(['h2', 'i2', 'i1', 'i3', 'h1', 'i5', 'i4']))
 
+    def test_from_response_xpath(self):
+        response = _buildresponse(
+            """<form action="post.php" method="POST">
+            <input type="hidden" name="one" value="1">
+            <input type="hidden" name="two" value="2">
+            </form>
+            <form action="post2.php" method="POST">
+            <input type="hidden" name="three" value="3">
+            <input type="hidden" name="four" value="4">
+            </form>""")
+        r1 = self.request_class.from_response(response, formxpath="//form[@action='post.php']")
+        fs = _qs(r1)
+        self.assertEqual(fs['one'], ['1'])
+
+        r1 = self.request_class.from_response(response, formxpath="//form/input[@name='four']")
+        fs = _qs(r1)
+        self.assertEqual(fs['three'], ['3'])
+
+        self.assertRaises(ValueError, self.request_class.from_response,
+                          response, formxpath="//form/input[@name='abc']")
 
 def _buildresponse(body, **kwargs):
     kwargs.setdefault('body', body)
